/* SPDX-License-Identifier: GPL-2.0 */
/*
 */

#include <config.h>
#include <asm-offsets.h>
#include <asm/addrspace.h>
#include <asm/asm.h>
#include <asm/regdef.h>
#include <asm/mipsregs.h>
#include <asm/sysreg.h>
#include <asm/pmu.h>
#include <asm/baikal_hw.h>

.text
.set noreorder
.set noat

#define CALL(x)         \
        la      t9, x;  \
        jalr    t9;     \
        nop /* Delay slot */

ENTRY(lowlevel_init)
	addiu	sp,sp,-8
	sw	ra,4(sp)
	ehb

	/* configure CPU frequency */
	CALL    (llenv_configure_corepll)

	/* init TLBs. */
	CALL    (llenv_init_tlb)
	CALL    (llenv_init_caches)
	CALL    (llenv_init_regs)

#ifdef DEBUG
	mfc0	a0, CP0_CONFIG
	PTR_LA	t9,printhex8
	jalr	t9
	nop

	li	a0,'\n'
	PTR_LA	t9,printch
	jalr	t9
	nop
#endif
	lw	ra,4(sp)
	jr	ra
	addiu	sp,sp,8
END(lowlevel_init)

llenv_configure_corepll:
	/* Base PMU address */
	li  t0, BAIKAL_PLL_BASE
	/* Core PLL control value */
	li  t1, BK_PMU_COREPLL_CTL_VAL
	/* Timeout */
	li  t2, 0x1000
	/* Store new value for Core PLL */
	sw  t1, 0x00(t0)
	sync
	/* Wait for PLL LOCK bit */
1:	lw  t1, 0x00(t0)
	ext t1, t1, PMU_COREPLL_CTL_LOCK_POS, PMU_COREPLL_CTL_LOCK_BITS
	bnel    t1, zero, 2f
	addi    t2, t2, -1
	bne t2, zero, 1b
	nop
	wait
2:	jr ra
	nop
