// SPDX-License-Identifier: GPL-2.0+

#include <common.h>
#include <cpu.h>
#include <dm.h>
#include <errno.h>
#include <asm/mipsregs.h>

DECLARE_GLOBAL_DATA_PTR;

static int bet1_cpu_get_desc(const struct udevice *dev, char *buf, int size)
{
	snprintf(buf, size, "MIPS32 P5600 (Rev 1.0)");
	return 0;
}

static int bet1_cpu_get_info(const struct udevice *dev, struct cpu_info *info)
{
	info->cpu_freq = gd->cpu_clk;
	info->features = 1 << CPU_FEAT_L1_CACHE;
	info->features |= 1 << CPU_FEAT_MMU;

	return 0;
}

#ifdef CONFIG_BAIKAL_T1
static int be_cpu_get_count(const struct udevice *dev)
{
	return 2;
}
#else
/* borrowed from riscv driver */
static int be_cpu_get_count(const struct udevice *dev)
{
	ofnode node;
	int num = 0;

	ofnode_for_each_subnode(node, dev_ofnode(dev->parent)) {
		const char *device_type;

		/* skip if hart is marked as not available in the device tree */
		if (!ofnode_is_available(node))
			continue;

		device_type = ofnode_read_string(node, "device_type");
		if (!device_type)
			continue;
		if (strcmp(device_type, "cpu") == 0)
			num++;
	}

	return num;
}
#endif /* CONFIG_BAIKAL_T1 */

static int be_cpu_get_vendor(const struct udevice *dev, char *buf, int size)
{
	snprintf(buf, size, "Baikal Electronics");
	return 0;
}

int baikal_cpu_bind(struct udevice *dev)
{
	struct cpu_platdata *plat = dev_get_parent_platdata(dev);

	plat->cpu_id = dev_read_u32_default(dev, "reg", -1);
	plat->device_id = read_c0_prid();
	plat->timebase_freq = CONFIG_SYS_MIPS_TIMER_FREQ;

	return 0;
}

static const struct cpu_ops baikal_cpu_ops = {
	.get_desc	= bet1_cpu_get_desc,
	.get_info	= bet1_cpu_get_info,
	.get_count	= be_cpu_get_count,
	.get_vendor 	= be_cpu_get_vendor,
};

static const struct udevice_id baikal_cpu_ids[] = {
	{ .compatible = "be,cpu" },
	{ }
};

U_BOOT_DRIVER(baikal_cpu) = {
	.name = "baikal_cpu",
	.id = UCLASS_CPU,
	.of_match = baikal_cpu_ids,
	.bind = baikal_cpu_bind,
	.ops = &baikal_cpu_ops,
	.flags = DM_FLAG_PRE_RELOC,
};
